Unix pipe for use with Mio.
See the new_pipe documentation.
new_pipe
Currently supported platforms:
The most notable exception in the list is Windows. If you want to contribute a port to Windows please see issue #4.